@@ -26,6 +26,7 @@
 
 #undef GTK_DISABLE_DEPRECATED
 
+#include <config.h>
 #include <string.h> /* memset */
 
 #include "gtklist.h"
@@ -34,6 +35,7 @@
 #include "gtksignal.h"
 #include "gtklabel.h"
 #include "gtkmarshalers.h"
+#include "gtkalias.h"
 
 enum {
   SELECTION_CHANGED,
@@ -266,8 +268,9 @@ gtk_list_class_init (GtkListClass *class)
 		    GTK_TYPE_NONE, 1,
 		    GTK_TYPE_WIDGET);
   
-  gtk_object_add_arg_type ("GtkList::selection_mode",
-			   GTK_TYPE_SELECTION_MODE, GTK_ARG_READWRITE,
+  gtk_object_add_arg_type ("GtkList::selection-mode",
+			   GTK_TYPE_SELECTION_MODE, 
+			   GTK_ARG_READWRITE | G_PARAM_STATIC_NAME,
 			   ARG_SELECTION_MODE);
 }
 
@@ -553,7 +556,7 @@ gtk_list_motion_notify (GtkWidget      *widget,
       if (list->htimer == 0)
 	{
 	  list->htimer = g_timeout_add
-	    (SCROLL_TIME, (GtkFunction) gtk_list_horizontal_timeout, widget);
+	    (SCROLL_TIME, (GSourceFunc) gtk_list_horizontal_timeout, widget);
 	  
 	  if (!((x < adj->value && adj->value <= 0) ||
 		(x > adj->value + adj->page_size &&
@@ -601,7 +604,7 @@ gtk_list_motion_notify (GtkWidget      *widget,
   if (!((y < 0 && focus_row == 0) ||
 	(y > widget->allocation.height && focus_row >= length - 1)))
     list->vtimer = g_timeout_add (SCROLL_TIME,
-				  (GtkFunction) gtk_list_vertical_timeout,
+				  (GSourceFunc) gtk_list_vertical_timeout,
 				  list);
 
   if (row != focus_row)
@@ -2616,3 +2619,6 @@ gtk_list_drag_begin (GtkWidget      *widget,
 	}
     }
 }
+
+#define __GTK_LIST_C__
+#include "gtkaliasdef.c"
