@@ -19,9 +19,9 @@
 
 
 #include <config.h>
-#include "gtkalias.h"
 #include "gtktreesortable.h"
 #include "gtkmarshalers.h"
+#include "gtkalias.h"
 
 static void gtk_tree_sortable_base_init (gpointer g_class);
 
@@ -94,10 +94,12 @@ gtk_tree_sortable_sort_column_changed (GtkTreeSortable *sortable)
  * @order: The #GtkSortType to be filled in
  * 
  * Fills in @sort_column_id and @order with the current sort column and the
- * order, if applicable.  If the sort column is not set, then FALSE is returned,
- * and the values in @sort_column_id and @order are unchanged.
-  * 
- * Return value: %TRUE, if the sort column has been set
+ * order.  It returns %TRUE unless the @sort_column_id is 
+ * %GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID or 
+ * %GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID.
+ * 
+ * Return value: %TRUE if the sort column is not one of the special sort
+ *   column ids.
  **/
 gboolean
 gtk_tree_sortable_get_sort_column_id (GtkTreeSortable  *sortable,
@@ -149,8 +151,8 @@ gtk_tree_sortable_set_sort_column_id (GtkTreeSortable  *sortable,
  * gtk_tree_sortable_set_sort_func:
  * @sortable: A #GtkTreeSortable
  * @sort_column_id: the sort column id to set the function for
- * @sort_func: The sorting function
- * @user_data: User data to pass to the sort func, or %NULL
+ * @sort_func: The comparison function
+ * @user_data: User data to pass to @sort_func, or %NULL
  * @destroy: Destroy notifier of @user_data, or %NULL
  * 
  * Sets the comparison function used when sorting to be @sort_func.  If the
@@ -180,13 +182,14 @@ gtk_tree_sortable_set_sort_func (GtkTreeSortable        *sortable,
 /**
  * gtk_tree_sortable_set_default_sort_func:
  * @sortable: A #GtkTreeSortable
- * @sort_func: The sorting function
- * @user_data: User data to pass to the sort func, or %NULL
+ * @sort_func: The comparison function
+ * @user_data: User data to pass to @sort_func, or %NULL
  * @destroy: Destroy notifier of @user_data, or %NULL
  * 
- * Sets the default comparison function used when sorting to be @sort_func.  If
- * the current sort column id of @sortable is
- * %GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, then the model will sort using this function.
+ * Sets the default comparison function used when sorting to be @sort_func.  
+ * If the current sort column id of @sortable is
+ * %GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, then the model will sort using 
+ * this function.
  *
  * If @sort_func is %NULL, then there will be no default comparison function.
  * This means that once the model  has been sorted, it can't go back to the
@@ -235,3 +238,6 @@ gtk_tree_sortable_has_default_sort_func (GtkTreeSortable *sortable)
   
   return (* iface->has_default_sort_func) (sortable);
 }
+
+#define __GTK_TREE_SORTABLE_C__
+#include "gtkaliasdef.c"
